##  Limitations
While the Lucidchart integration lets you import and export diagrams, the following limitations apply:
  * The integration does not synchronize any inventory data (for example, fact sheets and relations). Diagrams consist solely of static shapes, with no dynamic data linkage.
  * Imported diagrams cannot be edited within SAP LeanIX. Modifications must be made directly in Lucidchart.
